pub(crate) struct Incomplete {
pub(crate) buffer: [u8; 4],
pub(crate) buffer_len: u8,
}Fields
buffer: [u8; 4]buffer_len: u8Implementations
Sourceimpl Incomplete
impl Incomplete
pub(crate) fn new(bytes: &[u8]) -> Self
Sourcepub(crate) fn try_complete<'input>(
&mut self,
input: &'input [u8],
) -> Option<Completed<'_, 'input>>
pub(crate) fn try_complete<'input>( &mut self, input: &'input [u8], ) -> Option<Completed<'_, 'input>>
None: still incomplete, calltry_completeagain with more input. If no more input is available, this is invalid byte sequence.Some(completed): We’re done with thisIncomplete, with either a valid chunk on invalid byte sequence incompleted.result. To keep decoding, passcompleted.remaining_inputtodecode().
fn take_buffer(&mut self) -> &[u8] ⓘ